@@ -1,6 +1,6 @@
 package Tapper::Schema::TestrunDB::Result::Testrun;
 our $AUTHORITY = 'cpan:TAPPER';
-$Tapper::Schema::TestrunDB::Result::Testrun::VERSION = '5.0.11';
+$Tapper::Schema::TestrunDB::Result::Testrun::VERSION = '5.0.12';
 # ABSTRACT: Tapper - Containing Testruns
 
 use 5.010;
@@ -145,12 +145,27 @@ __PACKAGE__->has_many(
     { 'foreign.testrun_id'  => 'self.id' },
 );
 
+__PACKAGE__->has_many(
+    testrun_requested_resource => "${basepkg}::TestrunRequestedResource",
+    { 'foreign.testrun_id' => 'self.id' },
+);
+
+__PACKAGE__->has_many(
+    testrun_dependencies => "${basepkg}::TestrunDependency",
+    { 'foreign.depender_testrun_id' => 'self.id' }
+);
+
 # * : *
 __PACKAGE__->many_to_many(
     preconditions           => "testrun_precondition",
     'precondition'
 );
 
+__PACKAGE__->many_to_many(
+    depending_testruns => "testrun_dependencies",
+    'dependee'
+);
+
 # -------------------- methods on results --------------------
 
 
@@ -170,6 +185,13 @@ sub to_string
 }
 
 
+sub claimed_resources {
+        my ($self) = @_;
+        return map { $_->selected_resource } $self->testrun_requested_resource
+          ->search({ 'selected_resource_id' => { '!=', undef } }, { 'prefetch' => 'selected_resource' })->all();
+}
+
+
 sub is_member
 {
         my ($head, @tail) = @_;
@@ -233,12 +255,14 @@ sub rerun
         # prepare job scheduling infos
         my $testrunscheduling = $self->result_source->schema->resultset('TestrunScheduling')->search({ testrun_id => $self->id }, {rows => 1})->first;
         my ($queue_id, $host_id, $auto_rerun, $requested_features, $requested_hosts);
+        my @resource_requests;
         if ($testrunscheduling) {
                 $queue_id           = $testrunscheduling->queue_id;
                 $host_id            = $testrunscheduling->host_id;
                 $auto_rerun         = $testrunscheduling->auto_rerun;
                 $requested_features = $testrunscheduling->requested_features;
                 $requested_hosts    = $testrunscheduling->requested_hosts;
+                @resource_requests  = $testrunscheduling->requested_resources;
         } else {
                 my $queue = $self->result_source->schema->resultset('Queue')->search({ name => "AdHoc"}, {rows => 1})->first;
                 if (not $queue) {
@@ -273,6 +297,10 @@ sub rerun
                         $assigned_host->insert;
                 }
         }
+        # copy resource requests
+        foreach my $request (@resource_requests) {
+                $testrun_new->add_requested_resource_by_id(map { $_->resource_id } $request->alternatives);
+        }
 
         # assign preconditions
         my $preconditions = $self->preconditions->search({}, {order_by => 'succession'});
@@ -368,6 +396,49 @@ sub sqlt_deploy_hook
         $sqlt_table->add_index(name => 'testrun_idx_created_at',   fields => ['created_at']);
 }
 
+
+sub add_requested_resource_by_name {
+        my $self = shift;
+        my @alternatives = @_;
+
+        my $schema = $self->result_source->schema;
+
+        my @resource_objects;
+        eval {
+                @resource_objects = map {
+                        $schema->resultset('Resource')->search({ name => $_ })->first
+                          or die "Resource $_ does not exist";
+                } @alternatives;
+                1;
+        };
+
+        if ($@) {
+                return 0;
+        }
+
+        return $self->add_requested_resource_by_id(map { $_->id } @resource_objects);
+}
+
+
+sub add_requested_resource_by_id {
+        my $self = shift;
+        my @resource_ids = @_;
+
+        my $schema = $self->result_source->schema;
+
+        my $request = $schema
+            ->resultset('TestrunRequestedResource')
+            ->create({ testrun_id => $self->id });
+
+        foreach my $resource_id (@resource_ids) {
+                $schema
+                    ->resultset('TestrunRequestedResourceAlternative')
+                    ->create({ request_id => $request->id, resource_id => $resource_id });
+        }
+
+        return 1;
+}
+
 1;
 
 __END__
@@ -384,6 +455,10 @@ Tapper::Schema::TestrunDB::Result::Testrun - Tapper - Containing Testruns
 
 Return printable representation.
 
+=head2 claimed_resources
+
+Resources that have been assigned to this Testrun either currently or in the past.
+
 =head2 is_member($head, @tail)
 
 Checks if the first element is already in the list of the remaining
@@ -438,6 +513,24 @@ Disconnect list of preconditions from a testrun.
 
 Add useful indexes at deploy time.
 
+=head2 add_requested_resource_by_name
+
+Add a resource request to the testrun using resource names. Specify multiple
+resources to provide alternatives. When the testrun is running one of these is
+reserved to the testrun.
+
+@param @alternatives resource names
+@returns successful
+
+=head2 add_requested_resource_by_id
+
+Add a resource request to the testrun using resource ids. Specify multiple
+resources to provide alternatives. When the testrun is running one of these is
+reserved to the testrun.
+
+@param @resource_ids resource ids
+@returns successful
+
 =head1 AUTHORS
 
 =over 4
@@ -454,7 +547,7 @@ Tapper Team <tapper-ops@amazon.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2019 by Advanced Micro Devices, Inc..
+This software is Copyright (c) 2024 by Advanced Micro Devices, Inc.
 
 This is free software, licensed under:
 
