@@ -1,7 +1,7 @@
--- 
+--
 -- Created by SQL::Translator::Producer::MySQL
 -- Created on Thu Mar 10 12:06:40 2016
--- 
+--
 SET foreign_key_checks=0;
 
 DROP TABLE IF EXISTS chart_axis_types;
@@ -885,5 +885,69 @@ CREATE TABLE chart_tiny_url_relations (
   CONSTRAINT chart_tiny_url_relations_fk_chart_tiny_url_line_id FOREIGN KEY (chart_tiny_url_line_id) REFERENCES chart_tiny_url_lines (chart_tiny_url_line_id) ON DELETE CASCADE ON UPDATE CASCADE
 ) ENGINE=InnoDB;
 
-SET foreign_key_checks=1;
+--
+-- Table: resource
+--
 
+DROP TABLE IF EXISTS resource;
+
+CREATE TABLE resource (
+  id INTEGER PRIMARY KEY NOT NULL auto_increment,
+  name VARCHAR(255) DEFAULT '',
+  comment VARCHAR(255) DEFAULT '',
+  active TINYINT NOT NULL DEFAULT 0,
+  used_by_scheduling_id INT(11),
+  created_at TIMESTAMP DEFAULT CURRENT_TIMESTAMP,
+  updated_at DATETIME,
+  FOREIGN KEY (used_by_scheduling_id) REFERENCES testrun_scheduling(id) ON DELETE SET NULL ON UPDATE CASCADE
+);
+
+--
+-- Table: testrun_requested_resource
+--
+
+DROP TABLE IF EXISTS testrun_requested_resource;
+
+CREATE TABLE testrun_requested_resource (
+  id INTEGER PRIMARY KEY NOT NULL auto_increment,
+  testrun_id INT(11) NOT NULL,
+  selected_resource_id INT(11),
+  FOREIGN KEY (selected_resource_id) REFERENCES resource(id) ON DELETE SET NULL,
+  FOREIGN KEY (testrun_id) REFERENCES testrun(id) ON DELETE CASCADE ON UPDATE CASCADE
+);
+CREATE INDEX testrun_requested_resource_idx_selected_resource_id ON testrun_requested_resource (selected_resource_id);
+CREATE INDEX testrun_requested_resource_idx_testrun_id ON testrun_requested_resource (testrun_id);
+
+--
+-- Table: testrun_requested_resource_alternative
+--
+
+DROP TABLE IF EXISTS testrun_requested_resource_alternative;
+
+CREATE TABLE testrun_requested_resource_alternative (
+  id INTEGER PRIMARY KEY NOT NULL auto_increment,
+  request_id INT(11) NOT NULL,
+  resource_id INT(11) NOT NULL,
+  FOREIGN KEY (request_id) REFERENCES testrun_requested_resource(id) ON DELETE CASCADE ON UPDATE CASCADE,
+  FOREIGN KEY (resource_id) REFERENCES resource(id) ON DELETE CASCADE
+);
+CREATE INDEX testrun_requested_resource_alternative_idx_request_id ON testrun_requested_resource_alternative (request_id);
+CREATE INDEX testrun_requested_resource_alternative_idx_resource_id ON testrun_requested_resource_alternative (resource_id);
+
+--
+-- Table: testrun_dependency;
+--
+
+DROP TABLE IF EXISTS testrun_dependency;
+
+CREATE TABLE testrun_dependency (
+  dependee_testrun_id INT(11) NOT NULL,
+  depender_testrun_id INT(11) NOT NULL,
+  PRIMARY KEY (dependee_testrun_id, depender_testrun_id),
+  FOREIGN KEY (dependee_testrun_id) REFERENCES testrun(id) ON DELETE CASCADE,
+  FOREIGN KEY (depender_testrun_id) REFERENCES testrun(id) ON DELETE CASCADE ON UPDATE CASCADE
+);
+CREATE INDEX testrun_dependency_idx_dependee_testrun_id ON testrun_dependency (dependee_testrun_id);
+CREATE INDEX testrun_dependency_idx_depender_testrun_id ON testrun_dependency (depender_testrun_id);
+
+SET foreign_key_checks=1;
